@@ -44,6 +44,8 @@ async def sync_preseem_model(preseem_model, nm_model, company_uuid, system=None,
         for site in sites.values():
             # Create site if it doesn't exist (by name or source_id)
             if site not in model_sites:
+                if verbose:
+                    logging.info('Create site: %s', site)
                 model_sites[site] = await preseem_model.Site.Create(company_uuid=company_uuid, name=site)
                 if verbose:
                     logging.info('Created site: %s', model_sites[site])
@@ -54,6 +56,8 @@ async def sync_preseem_model(preseem_model, nm_model, company_uuid, system=None,
             if not model_site:
                 continue  # shouldn't be possible
             if (model_site.uuid, ap.attributes['topology1']) not in model_elems:
+                if verbose:
+                    logging.info('Create element: %s', ap)
                 r = await preseem_model.Element.Create(company_uuid=company_uuid, site_uuid=model_site.uuid, name=ap.attributes['topology1'], management_ip=ap.attributes.get('ip_address'))
                 if verbose:
                     logging.info('Created element: %s', r)
